aboutsummaryrefslogtreecommitdiffstats
path: root/becommands/help.py
diff options
context:
space:
mode:
authorW. Trevor King <wking@drexel.edu>2009-07-29 15:56:10 -0400
committerW. Trevor King <wking@drexel.edu>2009-07-29 15:56:10 -0400
commitdcfe9d5e292fa4a405fafb4bdd6d9e2070f30fa9 (patch)
treef9e9c8d2ba5190d1a71046cdb5fb3abdc0fcf74f /becommands/help.py
parent4e8882e74aad64859a16f17fa6bef8c04b33913d (diff)
parent22a38de80ee11ada710bc6766798ca608f938307 (diff)
downloadbugseverywhere-dcfe9d5e292fa4a405fafb4bdd6d9e2070f30fa9.tar.gz
Merged interactive email interface
Diffstat (limited to 'becommands/help.py')
-rw-r--r--becommands/help.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/becommands/help.py b/becommands/help.py
index a8ae338..a8f346a 100644
--- a/becommands/help.py
+++ b/becommands/help.py
@@ -19,9 +19,11 @@
from libbe import cmdutil, utility
__desc__ = __doc__
-def execute(args):
+def execute(args, manipulate_encodings=False):
"""
- Print help of specified command.
+ Print help of specified command (the manipulate_encodings argument
+ is ignored).
+
>>> execute(["help"])
Usage: be help [COMMAND]
<BLANKLINE>